part.PartCantusScoreTemplate
============================

.. abjad-lineage:: abjad.demos.part.PartCantusScoreTemplate.PartCantusScoreTemplate

.. autoclass:: abjad.demos.part.PartCantusScoreTemplate.PartCantusScoreTemplate

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.demos.part.PartCantusScoreTemplate.PartCantusScoreTemplate.__call__
      ~abjad.demos.part.PartCantusScoreTemplate.PartCantusScoreTemplate.__eq__
      ~abjad.demos.part.PartCantusScoreTemplate.PartCantusScoreTemplate.__format__
      ~abjad.demos.part.PartCantusScoreTemplate.PartCantusScoreTemplate.__ne__
      ~abjad.demos.part.PartCantusScoreTemplate.PartCantusScoreTemplate.__repr__

Bases
-----

- :py:class:`abjad.tools.abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Special methods
---------------

.. automethod:: abjad.demos.part.PartCantusScoreTemplate.PartCantusScoreTemplate.__call__
   :noindex:

.. automethod:: abjad.demos.part.PartCantusScoreTemplate.PartCantusScoreTemplate.__eq__
   :noindex:

.. automethod:: abjad.demos.part.PartCantusScoreTemplate.PartCantusScoreTemplate.__format__
   :noindex:

.. automethod:: abjad.demos.part.PartCantusScoreTemplate.PartCantusScoreTemplate.__ne__
   :noindex:

.. automethod:: abjad.demos.part.PartCantusScoreTemplate.PartCantusScoreTemplate.__repr__
   :noindex:
